==> CGContentUtils-1.3.2.tar.gz: CGContentUtils/lang/en_US.php <==
<?php
#A
$lang['add_block'] = 'Add a New Block';
$lang['advanced_content_copy'] = 'Advanced Copy of Content';
$lang['advanced_copy'] = 'Advanced Copy';
$lang['ask_delete_block'] = 'Do you really want to delete this block?';
$lang['ask_really_import'] = 'Are you sure you want to import this code, considering the warnings above';
$lang['ask_really_uninstall'] = 'Are you sure you want to do this?';
$lang['available_items'] = 'Available Items';
$lang['available_templates'] = 'Available Code';

#B
$lang['blocks'] = 'Blocks';
$lang['blocktype_textinput'] = 'Text Input';
$lang['blocktype_textarea'] = 'Text Area';
$lang['blocktype_dropdown'] = 'Dropdown';
$lang['blocktype_checkbox'] = 'Checkbox';
$lang['blocktype_file_selector'] = 'File Selector';
$lang['blocktype_pageselector'] = 'Page Selector';
$lang['blocktype_radiobuttons'] = 'Radio Buttons';

#C
$lang['cancel'] = 'Cancel';
$lang['content'] = 'Content';
$lang['contents_of_file'] = 'Scanned Contents of File';
$lang['copy'] = 'Copy';

#D
$lang['default_value'] = 'Default Value';
$lang['delete'] = 'Delete';

#E
$lang['edit'] = 'Edit';
$lang['error_broken_xml'] = 'The XML file specified is invalid';
$lang['error_copycontent_invalid_name'] = 'The title specified for copying id=%d is invalid';
$lang['error_copycontent_invalid_menutext'] = 'The menutext specified for copying id=%d is invalid';
$lang['error_missing_param'] = 'A required parameter was missing or invalid';
$lang['error_nameexists'] = 'An item by that name alreaady exists';
$lang['error_nocontentselected'] = 'No content was selected';
$lang['error_notfound'] = 'Item not found';
$lang['error_nothingtoimport'] = 'The XML file specified did not contain any information that could be imported into this installation (no compatible modules, or GCBs or UDTs)';
$lang['error_nothingselected'] = 'No items were selected';
$lang['error_permission_denied'] = 'Permission Denied';
$lang['error_upload'] = 'File upload failed';
$lang['error_uploadnotfound'] = 'Uploaded file cound not be found';
$lang['export'] = 'Export';
$lang['export_children'] = 'Export Children';
$lang['export_code'] = 'Export Code';
$lang['export_content'] = 'Export Content';
$lang['extra'] = 'Extra';

#F
$lang['file'] = 'XML File';
$lang['file_selector'] = 'File Selector';
$lang['friendlyname'] = 'Calguys Content Utlities';

#G
$lang['global_content_block'] = 'Global Content Block (GCB)';

#H

#I
$lang['info_available_items'] = 'Select an item below to see the exportable templates or code that can be exported';
$lang['info_blockname'] = 'Use only alphanumeric characters, underscores and dashes';
$lang['info_blockprompt'] = 'Specify a human readable prompt';
$lang['info_dropdown_options'] = 'Specify the options for the dropdown.  One option per line.  Specify values for each option by separating them with a pipe character';
$lang['info_excludeprefix'] = 'Exclude files with these prefixes (comma separated list)';
$lang['info_export_code'] = 'Export selected module templates, global content blocks, and module templates to an XML file for use on another web site';
$lang['info_filetypes'] = 'Specify a comma separated list of file extensions. i.e: pdf,jpg,doc';
$lang['info_final_import_code'] = 'The items selected for import  are be displayed below.  Items that represent an overwrite are hilighted in <span style="color: yellow;">yellow</span>. Please confirm that you really want to do this.<br/><strong>Note:</strong> It is possible by continuing that you may overwrite valid working templates.<br/>
<strong>Note:</strong> Some modules do not support multiple templates for each template type, therefore it may be necessary to overwrite some templates for them to have any effect.<br/>
<strong>Note:</strong> This module does not perform any modifications to the imported templates to check for references to pages, or existing module calls.  You may have to visit each template individually to customize its behavior for your site.';
$lang['info_import_code'] = 'Allows importing selected GBBs, UDTs and Module templates from an XML file.<br/><strong>Note:</strong> This is an advanced tool.  This feature allows overwriting templates into an existing syte.  Use with caution!';
$lang['info_scanned_file'] = 'Below are the scanned contents of the XML file supplied.  You may preview the items listed and select some for import.  You may optionally specify a new name for imported templates.';
$lang['import'] = 'Import';
$lang['import_code'] = 'Import Code';
$lang['import_content'] = 'Import Content';
$lang['import_name'] = 'Import Name';

#J

#K

#L
$lang['list_gcbs'] = 'Global Content Blocks';
$lang['list_udts'] = 'User Defined Tags';

#M
$lang['moddescription'] = 'A module with utilities and tools to aide in content management';
$lang['module'] = 'Module';
$lang['modules'] = 'Modules';
$lang['module_template'] = 'Module Template';
$lang['msg_blockadded'] = 'Block Successfully Added';
$lang['msg_blockupdated'] = 'Block values updated';
$lang['msg_cancelled'] = 'Operation cancelled';
$lang['msg_imported'] = '%d items imported from XML';

#N
$lang['name'] = 'Name';
$lang['new_alias'] = 'New Alias';
$lang['new_menutext'] = 'New MenuText';
$lang['new_name'] = 'New Name';
$lang['new_parent'] = 'New Parent';
$lang['next'] = 'Next';

#O

#P
$lang['parent'] = 'Parent';
$lang['postinstall'] = 'The CGContentUtils module has been installed';
$lang['postuninstall'] = 'The CGContentUtils module has been uninstalled';
$lang['preview'] = 'Preview';
$lang['prompt'] = 'Prompt';
$lang['prompt_cols'] = 'Columns';
$lang['prompt_dir'] = 'Directory <em>(relative to the uploads directory)</em>';
$lang['prompt_excludeprefix'] = 'Exclude files with these prefixes';
$lang['prompt_filetypes'] = 'Allowed File Types';
$lang['prompt_length'] = 'Length';
$lang['prompt_maxlength'] = 'Maximum Length';
$lang['prompt_options'] = 'Options';
$lang['prompt_page'] = 'Page';
$lang['prompt_recurse'] = 'Recurse into Subdirectories';
$lang['prompt_rows'] = 'Rows';
$lang['prompt_sortfiles'] = 'Sort Files by Name';
$lang['prompt_value'] = 'Value';

#Q

#R

#S
$lang['scan'] = 'Scan';
$lang['select_all'] = 'Select All';
$lang['start_page'] = 'Start Page';
$lang['submit'] = 'Submit';

#T
$lang['type'] = 'Type';

#U
$lang['usage'] = 'Usage';
$lang['userdefined_tag'] = 'User Defined Tag (UDT)';

#V

#W

#X
$lang['xml_file'] = 'XML File';

#Y

#Z

?>

==> CGContentUtils-1.3.6.tar.gz: CGContentUtils/lang/en_US.php <==
<?php
#A
$lang['add_block'] = 'Add a New Block';
$lang['advanced_content_copy'] = 'Advanced Copy of Content';
$lang['advanced_copy'] = 'Advanced Copy';
$lang['ask_delete_block'] = 'Do you really want to delete this block?';
$lang['ask_really_import'] = 'Are you sure you want to import this code, considering the warnings above';
$lang['ask_really_uninstall'] = 'Are you sure you want to do this?';
$lang['available_items'] = 'Available Items';
$lang['available_templates'] = 'Available Code';

#B
$lang['blocks'] = 'Blocks';
$lang['blocktype_textinput'] = 'Text Input';
$lang['blocktype_textarea'] = 'Text Area';
$lang['blocktype_dropdown'] = 'Dropdown';
$lang['blocktype_checkbox'] = 'Checkbox';
$lang['blocktype_file_selector'] = 'File Selector';
$lang['blocktype_pageselector'] = 'Page Selector';
$lang['blocktype_radiobuttons'] = 'Radio Buttons';

#C
$lang['cancel'] = 'Cancel';
$lang['content'] = 'Content';
$lang['contents_of_file'] = 'Scanned Contents of File';
$lang['copy'] = 'Copy';

#D
$lang['default_value'] = 'Default Value';
$lang['delete'] = 'Delete';

#E
$lang['edit'] = 'Edit';
$lang['error_broken_xml'] = 'The XML file specified is invalid';
$lang['error_copycontent_invalid_name'] = 'The title specified for copying id=%d is invalid';
$lang['error_copycontent_invalid_menutext'] = 'The menutext specified for copying id=%d is invalid';
$lang['error_missing_param'] = 'A required parameter was missing or invalid';
$lang['error_nameexists'] = 'An item by that name alreaady exists';
$lang['error_nocontentselected'] = 'No content was selected';
$lang['error_notfound'] = 'Item not found';
$lang['error_nothingtoimport'] = 'The XML file specified did not contain any information that could be imported into this installation (no compatible modules, or GCBs or UDTs)';
$lang['error_nothingselected'] = 'No items were selected';
$lang['error_permission_denied'] = 'Permission Denied';
$lang['error_upload'] = 'File upload failed';
$lang['error_uploadnotfound'] = 'Uploaded file cound not be found';
$lang['export'] = 'Export';
$lang['export_children'] = 'Export Children';
$lang['export_code'] = 'Export Code';
$lang['export_content'] = 'Export Content';
$lang['extra'] = 'Extra';

#F
$lang['file'] = 'XML File';
$lang['file_selector'] = 'File Selector';
$lang['friendlyname'] = 'Calguys Content Utilities';

#G
$lang['global_content_block'] = 'Global Content Block (GCB)';

#H

#I
$lang['info_available_items'] = 'Select an item below to see the exportable templates or code that can be exported';
$lang['info_blockname'] = 'Use only alphanumeric characters, underscores and dashes';
$lang['info_blockprompt'] = 'Specify a human readable prompt';
$lang['info_dropdown_options'] = 'Specify the options for the dropdown.  One option per line.  Specify values for each option by separating them with a pipe character';
$lang['info_excludeprefix'] = 'Exclude files with these prefixes (comma separated list)';
$lang['info_export_code'] = 'Export selected module templates, global content blocks, and module templates to an XML file for use on another web site';
$lang['info_filetypes'] = 'Specify a comma separated list of file extensions. i.e: pdf,jpg,doc';
$lang['info_final_import_code'] = 'The items selected for import  are be displayed below.  Items that represent an overwrite are hilighted in <span style="color: yellow;">yellow</span>. Please confirm that you really want to do this.<br/><strong>Note:</strong> It is possible by continuing that you may overwrite valid working templates.<br/>
<strong>Note:</strong> Some modules do not support multiple templates for each template type, therefore it may be necessary to overwrite some templates for them to have any effect.<br/>
<strong>Note:</strong> This module does not perform any modifications to the imported templates to check for references to pages, or existing module calls.  You may have to visit each template individually to customize its behavior for your site.';
$lang['info_import_code'] = 'Allows importing selected GBBs, UDTs and Module templates from an XML file.<br/><strong>Note:</strong> This is an advanced tool.  This feature allows overwriting templates into an existing syte.  Use with caution!';
$lang['info_scanned_file'] = 'Below are the scanned contents of the XML file supplied.  You may preview the items listed and select some for import.  You may optionally specify a new name for imported templates.';
$lang['import'] = 'Import';
$lang['import_code'] = 'Import Code';
$lang['import_content'] = 'Import Content';
$lang['import_name'] = 'Import Name';

#J

#K

#L
$lang['list_gcbs'] = 'Global Content Blocks';
$lang['list_udts'] = 'User Defined Tags';

#M
$lang['moddescription'] = 'A module with utilities and tools to aid in content management';
$lang['module'] = 'Module';
$lang['modules'] = 'Modules';
$lang['module_template'] = 'Module Template';
$lang['msg_blockadded'] = 'Block Successfully Added';
$lang['msg_blockupdated'] = 'Block values updated';
$lang['msg_cancelled'] = 'Operation cancelled';
$lang['msg_imported'] = '%d items imported from XML';

#N
$lang['name'] = 'Name';
$lang['new_alias'] = 'New Alias';
$lang['new_menutext'] = 'New MenuText';
$lang['new_name'] = 'New Name';
$lang['new_parent'] = 'New Parent';
$lang['next'] = 'Next';

#O

#P
$lang['parent'] = 'Parent';
$lang['postinstall'] = 'The CGContentUtils module has been installed';
$lang['postuninstall'] = 'The CGContentUtils module has been uninstalled';
$lang['preview'] = 'Preview';
$lang['prompt'] = 'Prompt';
$lang['prompt_cols'] = 'Columns';
$lang['prompt_dir'] = 'Directory <em>(relative to the uploads directory)</em>';
$lang['prompt_excludeprefix'] = 'Exclude files with these prefixes';
$lang['prompt_filetypes'] = 'Allowed File Types';
$lang['prompt_length'] = 'Length';
$lang['prompt_maxlength'] = 'Maximum Length';
$lang['prompt_options'] = 'Options';
$lang['prompt_page'] = 'Page';
$lang['prompt_recurse'] = 'Recurse into Subdirectories';
$lang['prompt_rows'] = 'Rows';
$lang['prompt_sortfiles'] = 'Sort Files by Name';
$lang['prompt_value'] = 'Value';

#Q

#R

#S
$lang['scan'] = 'Scan';
$lang['select_all'] = 'Select All';
$lang['start_page'] = 'Start Page';
$lang['submit'] = 'Submit';

#T
$lang['type'] = 'Type';

#U
$lang['usage'] = 'Usage';
$lang['userdefined_tag'] = 'User Defined Tag (UDT)';

#V

#W

#X
$lang['xml_file'] = 'XML File';

#Y

#Z

?>
